# Improper integrals

Proper integrals are [definite integrals](integration.md/#the-definite-integral) where the integrand $f$ is *continuous* on a *closed, finite* interval $[a,b]$. For positive $f$ it corresponds to the area of a **bounded region** of the plane, a region contained inside some disk of finite radius with centre at the origin. To extend the definite integral by allowing for two possibilities excluded in the situation described above.

1. There may exist $a=-\infty$ or $b=\infty$ or both.
2. $f$ may be unbounded as $x$ approaches $a$ or $b$ or both.

Integrals satisfying 1. are called **improper integrals of type I.** and integrals satisfying 2. are called **improper integrals of type II**.

## Improper integrals of type I

If $f$ is continuous on $[a,\infty]$, the improper integral of $f$ over $[a,\infty]$ is defined as a limit of proper integrals:

$$
\int_a^\infty f(x)dx = \lim_{R \to \infty} \int_a^R f(x)dx.
$$

Similarly, if $f$ is continuous on $[-\infty,b]$, then the improper integrals is defined as:

$$
\int_{-\infty}^b f(x)dx = \lim_{R \to -\infty} \int_R^b f(x)dx.
$$

In either case, if the limit exists, the improper integral **converges**. If the limit does not exist, the improper integral **diverges**. If the limit is $\infty$ or $-\infty$, the proper integral **diverges to (negative) infinity**.

## Improper integrals of type II

If $f$ is continuous on the interval $(a,b]$ and is possibly unbounded near $a$, the improper integral may be defined as:

$$
\int_a^b f(x)dx = \lim_{c \downarrow a} \int_c^b f(x)dx.
$$

Similarly, if $f$ is continuous on $[a,b)$ and is possibly unbounded near $b$, the improper integral may be defined as:

$$
\int_a^b f(x)dx = \lim_{c \uparrow b} \int_a^c f(x)dx.
$$

These improper integrals may also converge, diverge or diverge to (negative) infinity.

## p-integrals

Summerizing the behaviour of improper integrals of types I and II for powers of $x$ if $0 < a< \infty$, then:

1. 
$$
\int_a^\infty x^{-p}dx = 
    \begin{cases}
        \text{converges to } \frac{a^{1-p}}{p-1} \quad \text{if } p > 1, \\
        \text{diverges to } \infty \quad \text{if } p \leq 1.
    \end{cases}
$$


2. 
$$
\int_0^a x^{-p}dx =
    \begin{cases}
        \text{converges to } \frac{a^{1-p}}{1-p} \quad \text{if } p < 1, \\
        \text{diverges to } \infty \quad \text{if } p \geq 1.
    \end{cases}
$$

**Proof of 1:**

For $p=1$:

$$
\int_a^\infty x^{-1}dx = \lim_{R \to \infty} \int_a^R x^{-1}dx = \lim_{R \to \infty} (\ln R - \ln a) = \infty.
$$

For $p < 1$:

$$
\begin{array}{ll}
\int_a^\infty x^{-p}dx &= \lim_{R \to \infty} \int_a^R x^{-p}dx, \\
                       &= \lim_{R \to \infty} [\frac{x^{-p+1}}{-p+1}]_a^R, \\
                       &= \lim_{R \to \infty} \frac{R^{1-p}-a^{1-p}}{1-p} = \infty.
\end{array}
$$

For $p > 1$

$$
\begin{array}{ll}
\int_a^\infty x^{-p}dx &= \lim_{R \to \infty} \int_a^R x^{-p}dx, \\
                       &= \lim_{R \to \infty} [\frac{x^{-p+1}}{-p+1}]_a^R, \\
                       &= \lim_{R \to \infty} \frac{a^{-(p-1)}-R^{-(p-1)}}{p-1} = \frac{a^{1-p}}{p-1}.
\end{array}
$$

**Proof of 2:**

For $p=1$:

$$
\int_0^a x^{-1}dx = \lim_{c \space\downarrow\space 0} \int_c^a x^{-1}dx = \lim_{c \space\downarrow\space 0} (\ln a - \ln c) = \infty.
$$

For $p > 1$

$$
\begin{array}{ll}
\int_0^a x^{-p}dx &= \lim_{c \space\downarrow\space 0} \int_c^a x^{-p}dx, \\
                  &= \lim_{c \space\downarrow\space 0} [\frac{x^{-p+1}}{-p+1}]_c^a, \\
                  &= \lim_{c \space\downarrow\space 0} \frac{c^{-(p-1)} - a^{-(p-1)}}{p-1} = \infty.
\end{array}
$$

For $p < 1$:

$$
\begin{array}{ll}
\int_0^a x^{-p}dx &= \lim_{c \space\downarrow\space 0} \int_c^a x^{-p} dx, \\
                  &= \lim_{c \space\downarrow\space 0} [\frac{x^{-p+1}}{-p+1}]_c^a, \\
                  &= \lim_{c \space\downarrow\space 0} \frac{a^{1-p}-c^{1-p}}{1-p} = \frac{a^{1-p}}{1-p}.
\end{array}
$$

## Comparison theorem for integrals

Let $-\infty \leq a < b \leq \infty$, and suppose that functions $f$ and $g$ are continuous on the interval $(a,b)$ and satisfy $0 \leq f(x) \leq g(x)$. If $\int_a^b g(x)dx$ converges, then so does $\int_a^b f(x)dx$, and:

$$
\int_a^b f(x)dx \leq \int_a^b g(x)dx.
$$

Equivalently, if $\int_a^b f(x)dx$ diverges to $\infty$, then so does $\int_a^b g(x)dx$.

**Proof:** Since both integrands are nonnegative, there are only two possibilities for each integral: it can either converge to a nonnegative number or diverge to $\infty$. Since $f(x) \leq g(x)$ on $(a,b)$, it follows by the [properties of the definite integral](integration.md/#properties) that if $a < r < s < b$, then:

$$
\int_r^s f(x)dx \leq \int_r^s g(x)dx.
$$

By taking limits as $r \space\downarrow\space a$ and $s \space\uparrow\space b$.

### To prove convergence

To find a function $g$, such that 

1. $\forall x \in [a,\infty], \space 0 \leq f(x) \leq g(x)$.
2. $\int_0^\infty g(x)dx$ is convergent.

### To prove divergence

To find a function $f$ such that

1. $\forall x \in [a,\infty], \space g(x) \geq f(x) \geq 0$.
2. $\int_0^\infty f(x)dx$ is divergent.