# Inverse functions

## Injectivity

A function $f$ is called injective if for all $x_1,x_2 \in \mathrm{Dom}(f), \space x_1 \neq x_2$ implies that $f(x_1) \neq f(x_2).$ Meaning that for every $y \in \mathrm{Rang}(f)$ there is precisely one $x \in \mathrm{Dom}(f)$ such that $y = f(x)$. Meaning, every $x$ has an unique $y$.

## Inverse function

If $f$ is injective, then it has an inverse function $f^{-1}$. The value of $f^{-1}(x)$ is the unique number $y$ in the domain of $f$ for which $f(y) = x$. Thus,

$$
y = f^{-1}(x) \iff x = f(y)
$$

Suppose $f$ is a continuous function, $f$ is injective if $f$ is strictly increasing or decreasing. That is, $f' \leq 0 \vee f' \geq 0$.

### Derivative of inverse function

When $f$ is differentiable and injective $(f^{-1})'(x) = \frac{1}{f'(f^{-1}(x))}$.

**Proof:**

$$f(y) = x \implies f'(y) \frac{dy}{dx} = 1$$

$$\frac{dy}{dx} = \frac{1}{f'(y)} = \frac{1}{f'(f^{-1}(x))}$$

Without knowing the inverse function a value of the inverse derivative may be determined.

## The arcsine function

Always $\arcsin$ not $\sin^{-1}$ that is wrong since $\sin$ is not injective.

For $x \in [-\frac{\pi}{2},\frac{\pi}{2}] \space \arcsin(\sin x) = x$

For $x \in [-1,1] \space \sin(\arcsin x) = x$

The arccosine function is similar.

## Example question

Prove that $\forall x \geq 0$: $\arctan(x + 1) - \arctan(x) < \frac{1}{1 + x^2}$.

For $x = 0$: $\frac{\pi}{4} < 1$.

For $x > 0$: Consider the function $f(t) = \arctan(t)$ on the interval $[x, x+1]$. Apply the [Mean-value theorem](../differentation.md/#mean-value-theorem) of $f$ at the interval $[x,x+1]$,

$$\frac{f(x+1) - f(x)}{(x+1) - 1} = f'(c).$$

Let $\arctan(c) = y$ then, $c = \tan y$,

$$
\begin{array}{ll}
\frac{dy}{dc} (c = \tan y) &\implies 1 = \sec^2 (y) \frac{dy}{dc} = (\tan^2 y + 1) \frac{dy}{dc} \\
                           &\implies 1 = (c^2 + 1) \frac{dy}{dc} \\
                           &\implies \frac{dy}{dc} = \frac{1}{c^2 + 1}.
\end{array}
$$

Obtaining,

$$\arctan(x+1) - \arctan(x) = f'(c) = \frac{1}{c^2 + 1}.$$

For some $c \in (x,x+1)$, since $c > x$

$$\frac{1}{1 + c^2} < \frac{1}{1 + x^2},$$

thereby

$$\arctan(x+1) - \arctan(x) < \frac{1}{1 + x^2}.$$